@@ -622,11 +622,26 @@ class OculScholarsPortalPreservation(models.Model):
         :return: None
         """
 
+        if 'status' not in output or output['status'] is None:
+            status = 0
+        else:
+            status = output['status']
+
+        if 'verified' not in output or output['verified'] is None:
+            verified = 0
+        else:
+            verified = output['verified']
+
         if 'publisher' not in output or output['publisher'] is None:
             publisher = 'Default'
         else:
             publisher = output['publisher']
 
+        if 'title' not in output or output['title'] is None:
+            title = 'Unknown title'
+        else:
+            title = output['title']
+
         publisher, created = \
             Publisher.objects.get_or_create(name=publisher)
 
@@ -639,9 +654,9 @@ class OculScholarsPortalPreservation(models.Model):
             issue = issue if issue is not None else ''
 
             OculScholarsPortalPreservation.objects.create(
-                issn=output['issn'], title=output['title'],
+                issn=output['issn'], title=title,
                 preserved_volumes=volume, preserved_no=issue,
-                preserved=output['status'], verified=output['verification'],
+                preserved=status, verified=verified,
                 publisher=publisher
             )
 
