@@ -1,8 +1,11 @@
+import gc
 import logging
 import re
+import tracemalloc
 from csv import DictReader
 from io import StringIO
 
+import django
 import requests
 from crossref.restful import Etiquette, Works
 from django.db.models import QuerySet
@@ -265,14 +268,29 @@ def process_onix(xml_file, elements, callback) -> None:
 
     collect = False
 
+    count = 0
+
     for event, elem in ET.iterparse(xml_file, events=('start', 'end')):
 
         if event == 'end' and elem.tag == '{http://www.editeur.org/onix/' \
                                           'serials/SOH}HoldingsRecord':
             callback(current_object)
 
+            gc.collect()
+
             current_object = {'volumes': [], 'issues': []}
 
+            count = count + 1
+            stats = []
+
+            filters = [tracemalloc.Filter(inclusive=True, filename_pattern="*")]
+
+            if count % 100 == 0:
+                django.db.reset_queries()
+
+            # free memory (urgh)
+            elem.clear()
+
         # detect if it's an ISSN
         if event == 'start' \
                 and elem.tag == '{http://www.editeur.org/onix/' \
@@ -361,4 +379,6 @@ def normalize_issn(issn) -> str:
     :param issn: the ISSN
     :return: the normalized ISSN
     """
-    return f'{issn[0:4]}-{issn[4:8]}' if '-' not in issn else issn
+    issn = '' if issn is None else issn.strip()
+
+    return f'{issn[0:4]}-{issn[4:8]}' if issn and '-' not in issn else issn
